Struct win7_notifications::Notification[][src]

#[non_exhaustive]
pub struct Notification { pub icon: Vec<u8>, pub appname: String, pub summary: String, pub body: String, pub timeout: Timeout, }
Describes The notification

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
icon: Vec<u8>appname: Stringsummary: Stringbody: Stringtimeout: Timeout

Implementations

Constructs a new Notification.

Most fields are empty by default, only appname is initialized with the name of the current executable.

Overwrite the appname field used for Notification.

Set the summary.

Often acts as title of the notification. For more elaborate content use the body field.

Set the content of the body field.

Multiline textual content of the notification. Each line should be treated as a paragraph. html markup is not supported.

Set the icon field must be .ico byte array.

Set the timeout field.

Shows the Notification.

Requires an win32 event_loop to be running, otherwise the notification will close immediately.